==> zio-aws-lexmodelsv2_2.12-5.17.121.3-sources.jar: zio/aws/lexmodelsv2/model/SlotTypeCategory.scala <==
package zio.aws.lexmodelsv2.model
import scala.jdk.CollectionConverters._
sealed trait SlotTypeCategory {
  def unwrap: software.amazon.awssdk.services.lexmodelsv2.model.SlotTypeCategory
}
object SlotTypeCategory {
  def wrap(
      value: software.amazon.awssdk.services.lexmodelsv2.model.SlotTypeCategory
  ): zio.aws.lexmodelsv2.model.SlotTypeCategory = value match {
    case software.amazon.awssdk.services.lexmodelsv2.model.SlotTypeCategory.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.lexmodelsv2.model.SlotTypeCategory.CUSTOM =>
      val r = Custom
      r
    case software.amazon.awssdk.services.lexmodelsv2.model.SlotTypeCategory.EXTENDED =>
      val r = Extended
      r
    case software.amazon.awssdk.services.lexmodelsv2.model.SlotTypeCategory.EXTERNAL_GRAMMAR =>
      val r = ExternalGrammar
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.lexmodelsv2.model.SlotTypeCategory {
    override def unwrap
        : software.amazon.awssdk.services.lexmodelsv2.model.SlotTypeCategory =
      software.amazon.awssdk.services.lexmodelsv2.model.SlotTypeCategory.UNKNOWN_TO_SDK_VERSION
  }
  case object Custom extends zio.aws.lexmodelsv2.model.SlotTypeCategory {
    override def unwrap
        : software.amazon.awssdk.services.lexmodelsv2.model.SlotTypeCategory =
      software.amazon.awssdk.services.lexmodelsv2.model.SlotTypeCategory.CUSTOM
  }
  case object Extended extends zio.aws.lexmodelsv2.model.SlotTypeCategory {
    override def unwrap
        : software.amazon.awssdk.services.lexmodelsv2.model.SlotTypeCategory =
      software.amazon.awssdk.services.lexmodelsv2.model.SlotTypeCategory.EXTENDED
  }
  case object ExternalGrammar
      extends zio.aws.lexmodelsv2.model.SlotTypeCategory {
    override def unwrap
        : software.amazon.awssdk.services.lexmodelsv2.model.SlotTypeCategory =
      software.amazon.awssdk.services.lexmodelsv2.model.SlotTypeCategory.EXTERNAL_GRAMMAR
  }
}

==> zio-aws-lexmodelsv2_2.12-5.20.37.1-sources.jar: zio/aws/lexmodelsv2/model/SlotTypeCategory.scala <==
package zio.aws.lexmodelsv2.model
import scala.jdk.CollectionConverters._
sealed trait SlotTypeCategory {
  def unwrap: software.amazon.awssdk.services.lexmodelsv2.model.SlotTypeCategory
}
object SlotTypeCategory {
  def wrap(
      value: software.amazon.awssdk.services.lexmodelsv2.model.SlotTypeCategory
  ): zio.aws.lexmodelsv2.model.SlotTypeCategory = value match {
    case software.amazon.awssdk.services.lexmodelsv2.model.SlotTypeCategory.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.lexmodelsv2.model.SlotTypeCategory.CUSTOM =>
      val r = Custom
      r
    case software.amazon.awssdk.services.lexmodelsv2.model.SlotTypeCategory.EXTENDED =>
      val r = Extended
      r
    case software.amazon.awssdk.services.lexmodelsv2.model.SlotTypeCategory.EXTERNAL_GRAMMAR =>
      val r = ExternalGrammar
      r
    case software.amazon.awssdk.services.lexmodelsv2.model.SlotTypeCategory.COMPOSITE =>
      val r = Composite
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.lexmodelsv2.model.SlotTypeCategory {
    override def unwrap
        : software.amazon.awssdk.services.lexmodelsv2.model.SlotTypeCategory =
      software.amazon.awssdk.services.lexmodelsv2.model.SlotTypeCategory.UNKNOWN_TO_SDK_VERSION
  }
  case object Custom extends zio.aws.lexmodelsv2.model.SlotTypeCategory {
    override def unwrap
        : software.amazon.awssdk.services.lexmodelsv2.model.SlotTypeCategory =
      software.amazon.awssdk.services.lexmodelsv2.model.SlotTypeCategory.CUSTOM
  }
  case object Extended extends zio.aws.lexmodelsv2.model.SlotTypeCategory {
    override def unwrap
        : software.amazon.awssdk.services.lexmodelsv2.model.SlotTypeCategory =
      software.amazon.awssdk.services.lexmodelsv2.model.SlotTypeCategory.EXTENDED
  }
  case object ExternalGrammar
      extends zio.aws.lexmodelsv2.model.SlotTypeCategory {
    override def unwrap
        : software.amazon.awssdk.services.lexmodelsv2.model.SlotTypeCategory =
      software.amazon.awssdk.services.lexmodelsv2.model.SlotTypeCategory.EXTERNAL_GRAMMAR
  }
  case object Composite extends zio.aws.lexmodelsv2.model.SlotTypeCategory {
    override def unwrap
        : software.amazon.awssdk.services.lexmodelsv2.model.SlotTypeCategory =
      software.amazon.awssdk.services.lexmodelsv2.model.SlotTypeCategory.COMPOSITE
  }
}
